%
%                            MERL_Dock Time-Series

% $Log: merldock.m,v $
% Revision 1.8  2000/04/04 14:57:32  kwoklin
% Move server from euros to aspre.   klee
%
% Revision 1.7  2000/03/17 09:08:24  dbyrne
%
%
% Removed optionalvariables and selectableoptional, as they were
% not being used. -- dbyrne 00/03/17
%
% Revision 1.6  2000/03/16 05:27:22  dbyrne
%
%
% Changed some variable names to be a little more standard.
% dbyrne 00/03/14
%
% Revision 1.5  2000/02/22 19:47:53  kwoklin
% *** empty log message ***
%
% Revision 1.3  2000/02/22 19:07:16  kwoklin
% Modify longitude value. Convert time to decimal_year representation for gsodock. klee
%

% $Id: merldock.m,v 1.8 2000/04/04 14:57:32 kwoklin Exp $
% klee   02/22/2000
% Ruth Platner  07/06/99
%
% FUNCTIONS -- REQUIRED
GetFunctionName = 'getgsod';

% FUNCTIONS -- OPTIONAL
CatalogServer = nan;
URL_m_File = 'merldu';

% VARIABLES -- OPTIONAL
Server = 'http://aspre.gso.uri.edu/cgi-bin/dods/nph-ff/dods/merl/merl.dat';

% VARIABLES -- REQUIRED
LonRange = [-71.42 -71.42];;
LatRange = [41.49 41.49];
TimeRange = [1976.5 1999.5];
DepthRange = [0. 2.1];
Resolution = nan;

DataName = 'Water Column - MERL Dock Time-Series - URI';
TimeName = 'time';
LongitudeName = 'lon';
LatitudeName = 'lat';
DepthName = 'depth';
DepthUnits = 'Meters';

% these names tie in to the browser as recognized common strings
% linking different datasets
% there must be one DODSNAME for each selectable variable
DodsName1 = str2mat('lat','lon','time');
SelectableVariables = str2mat(str2mat('Nitrite','Total_Nitrate_Nitrite','Ammonium','Total_DIN',...
 'Phosphate','Silicate','Chlorophyll','Phaeopigment'),str2mat('Salinity','Sea_Temp',...
 'in_vivo_Fluorescence','DCMU_Fluorescence','Total_Zooplankton','Zooplankton_Biomass','pH_Value'));
% there must be one DODSNAME for each selectable variable
DodsName = str2mat(str2mat('NO2','NO3_NO2','NH4','Total_N','PO4','SiO4', ...
 'Chlorophyll','Phaeophytin'),str2mat('Salinity','Temp','In_vivo_flr', ...
 'DCMU_flr','Total_Zooplankton','Zoop_Biomass','pH'));

% note: DataNull is applied *before* scaling
DataNull = [NaN NaN NaN NaN ...
            -99.00 -99.00 -99.00 -99.00 -99 -99.00 -99.00 -99.00 -99.00 -99.00 ...
            -99.00 -99.00 -99 -99.00 -99.00];

Acknowledge = sprintf('%s\n\n%s\n%s\n%s\n%s', ...
    [ 'The author of this dataset is Candace A. Oviatt.', ...
      'The data were provided by the University of Rhode Island ', ...
      '(http://euros.gso.uri.edu/dods/merl/)',...
      'and accessed via the Distributed Oceanographic Data System ',...
      '(DODS: http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citations:  Lorenzen, C. J. 1966. A method for continuous ',...
      'measurement of in vivo chlorophyll concentration. Deep Sea ',...
      'Res. 13: 223-227.'],...
    [ 'Oviatt, C. A. and K. Hindle. 1994. Manual of biological and ',...
      'geochemical techniques in coastal areas. MERL Series Report ',...
      'No. 1, 3rd ed.'],...
    [ 'Strickland, J. D. H., and T. R. Parsons. 1972. A practical ',...
      'handbook of seawater analysis, 2nd ed. Bull. Fish. Res. Bd. ',...
      'Can.'],...
    [ 'Yentsch, C. S. and D. W. Menzel. 1963. A method for the ',...
      'determination of phytoplankton chlorophyll and phaeophytin ',...
      'by fluorescence. Deep-Sea. Res. 10: 221.']);
Data_Use_Policy = [];

Comments1 = sprintf('%s\n','',...
 '                               MERL Dock Time-Series',...
 '      ',...
'                   Parameter         Description                    Units',...
'                 ----------------------------------------------------------',...
'                   time              yearday                        decimal year      ',...
'                   depth             deployment depth               meters',...
'                   NO2               nitrite                        umoles/liter',...
'                   NO3_NO2           nitrate_nitrite                umoles/leter',...   
'                   NH4               ammonium                       umoles/liter',...
'                   Total_N           dissolved_inorganic_nitrogen   umoles/liter',...
'                   PO4               phosphate                      umoles/liter',...
'                   SiO4              silicate                       umoles/liter',...
'                   Chlorophyll       chlorophyll-a                  ug/liter',...
'                   Phaeophytin       phaeophytin-a                  ug/liter',...
'                   Salinity          salinity                       ppt',...
'                   Temp              sea temp                       degress C',...
'                   In_vivo_flr       in vivo fluorescence           relative units',...   
'                   DCMU_flr          DCMU added fluorescence        relative units',...
'                   Total_Zooplankton total zooplankton count        number/m3',...
'                   Zoop_Biomass      zooplankton biomass            mg/m3 - dry weight',...
'                   pH                pH value                       pH units  ',...
 '      ',...
 '      Methods',...
 '      ',...
 '      Samples were collected using two techniques. Surface water samples were',...
 '      collected from the dock at the Graduate School of Oceanography (GSO),',...
 '      University of Rhode Island and placed in an amber polyethylene bottle prior',...
 '      to measurement. Prior to 1997, samples were collected from the header tank',...
 '      at the Marine Ecosystems Research Laboratory. The header tank contained',...
 '      water continuously pumped (with a diaphragm pump shown to be nondestructive',...
 '      to zooplankton) from Narragansett Bay at the GSO dock from a depth of about',...
 '      2 m below the surface. In both cases, samples were typically collected in',...
 '      mid-morning (9:00 - 10:00 AM) at various stages of the tidal cycle. Detailed',...
 '      descriptions of the following procedures are noted in the Marine Ecosystems',...
 '      Research Laboratory (MERL) methods manual (Oviatt and Hindle, 1994).',...
 '      ',...
 '      Temperature of seawater was recorded using a thermometer. Salinity was',...
 '      monitored with a refractometer with a calibrated precision of + 0.5 ppt or a',...
 '      high precision (+ 0.005 ppt) Autosal.',...
 '      ',...
 '      pH was measured using glass electrode and electrometer-type pH meters. The',...
 '      pH meter was standardized with buffers (pH 9, pH7 and pH4) and was rechecked',...
 '      with a pH 7 buffer solution prior to sample analysis. Samples were siphoned',...
 '      from the amber sample bottle, taking care not to trap air in the bottles,',...
 '      and held in a temperature controlled water bath at in situ temperature.',...
 '      Samples were read within 1 h after collection. Precision was + 0.02 pH',...
 '      units.');
Comments2 = sprintf('%s\n','',...
 '      Dissolved inorganic nutrients (mol liter-1) were measured weekly from',...
 '      subsamples taken from the amber polyethylene bottles. Samples were analyzed',...
 '      on a Technicon AutoAnalyzer with standard procedures (similar to those',...
 '      outlined in Strickland and Parsons 1972). Samples were analyzed immediately',...
 '      or frozen for future analysis. Primary and secondary standards (in seawater)',...
 '      were used to calculate concentrations (Oviatt and Hindle 1994). Standard',...
 '      deviations were <0.05 mol liter-1 for all nutrients measured.',...
 '      ',...
 '      Replicate chlorophyll a (g liter-1) was measured weekly from 10-ml aliquots',...
 '      of water subsampled from the amber bottles. Samples were filtered through',...
 '      25-mm Whatman GF/F glass-fiber filters at 125 mm of Hg maximal vacuum. Two',...
 '      drops of 1% magnesium carbonate were added to each sample prior to',...
 '      filtration. Samples were extracted overnight in the freezer using 90%',...
 '      acetone and analyzed within 24 hours on a Turner Designs Model 10 Field',...
 '      Fluorometer (Yentsch and Menzel 1963; Lorenzen 1966). After the initial',...
 '      reading on the fluorometer, two drops of 10% HCl were added and a second',...
 '      reading taken. The second reading was used to calculate phaeopigments',...
 '      concentrations (g liter-1). Prior to 1996, chlorophyll was extracted by',...
 '      first grinding the filter for 1 min in 3 ml of 90% acetone. Grinding was',...
 '      accomplished using a glass grinding tube and teflon pestle attached to a',...
 '      motor drive. The extract slurry and rinses were transferred to a 10 ml',...
 '      Nalgene test tube and capped. The samples were allowed to extract for',...
 '      several minutes in the dark after which they were centrifuged, decanted and',...
 '      read. Using this technique, samples may have been stored temporarily (2',...
 '      weeks) in aluminum foil in the freezer until analysis.');
Comments3 = sprintf('%s\n','',...
 '      In vivo and DCMU fluorescence were measured from subsamples removed from the',...
 '      amber sample bottle after allowing at least a 10 min dark adaptation period.',...
 '      Samples were measured using a Turner Design Model 10 Field Fluorometer',...
 '      equipped for chlorophyll a analysis. To account for instrument drift, basic',...
 '      fluorescence procedures were slightly modified by using a coproporphyrin',...
 '      standard (Sigma Chem. Co., St. Louis, Mo.). In vivo and DCMU fluorescence',...
 '      were measured using separate 1-cm glass cuvettes containing approximately 10',...
 '      ml of sample. Two drops of saturated DCMU were added to the second cuvette,',...
 '      the solution was mixed and the enhanced fluorescence was recorded.',...
 '      ',...
 '      Zooplankton numbers and biomass were sampled by vertical net tow (64 mm',...
 '      mesh) filtering about 0.20 m3 water. Actual volume was determined with a',...
 '      flow meter. Zooplankton were preserved in 10% formalin, staged, identified,',...
 '      and enumerated. For biomass, samples were rinsed with deionized water to',...
 '      remove salt, frozen, freeze-dried and weighed to the nearest 0.1 mg.',...
 '      ');
Comments4 = sprintf('%s\n','',...
 '      Literature Cited',...
 '      ',...
 '      Lorenzen, C. J. 1966. A method for continuous measurement of in vivo',...
 '      chlorophyll concentration. Deep Sea Res. 13: 223-227.',...
 '      ',...
 '      Oviatt, C. A. and K. Hindle. 1994. Manual of biological and geochemical',...
 '      techniques in coastal areas. MERL Series Report No. 1, 3rd ed.',...
 '      ',...
 '      Strickland, J. D. H., and T. R. Parsons. 1972. A practical handbook of',...
 '      seawater analysis, 2nd ed. Bull. Fish. Res. Bd. Can.',...
 '      ',...
 '      Yentsch, C. S. and D. W. Menzel. 1963. A method for the determination of',...
 '      phytoplankton chlorophyll and phaeophytin by fluorescence. Deep-Sea. Res.',...
 '      10: 221.',...
 '      ',...
 '      For information on use of these data please contact:',...
 '      ',...
 '      Professor of Oceanography, Candace A. Oviatt',...
 '      Graduate School of Oceanography',...
 '      University of Rhode Island',...
 '      South Ferry Road',...
 '      Narragansett, RI 02882 USA',...
 '      ',...
 '      E-mail: coviatt@gso.uri.edu',...
 '      ',...
 '      Data Status: Final',...
 '      ');
Comments5 = sprintf('%s\n','',...
        '   ', ...
'    Time_Period_of_Content = ', ...
'         Beginning_Date: Aug. 25, 1976 (1976.65)', ...
'         Ending_Date:    Mar. 28, 1999 (1999.24)', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates (approximate): ', ...
'              West Bounding Coordinate: 71.4188 W ', ...
'              East Bounding Coordinate: 71.4188 W ', ...
'              South Bounding Coordinate: 41.4923 N ', ...
'              North Bounding Coordinate: 41.4923 N ', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address - si: ', ...
'               Prof. Candace A. Oviatt', ...
'               Graduate School of Oceanography',...
'               University of Rhode Island',...
'               South Ferry Road',...
'               Narragansett, RI 02882 USA',...
'               USA ', ...
'               Electronic Mail Address:INTERNET > coviatt@gso.uri.edu',...
'         Address - dods: ',...
'               Electronic Mail Address:INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2 Comments3 Comments4];
